import traceback

from cpl_core.configuration.configuration_model_abc import ConfigurationModelABC
from cpl_core.console import Console
from cpl_query.extension import List


class DiscordAuthenticationSettings(ConfigurationModelABC):

    def __init__(self):
        ConfigurationModelABC.__init__(self)

        self._client_secret = ''
        self._redirect_url = ''
        self._scope = List()
        self._token_url = ''
        self._auth_url = ''

    @property
    def client_secret(self) -> str:
        return self._client_secret

    @property
    def redirect_url(self) -> str:
        return self._redirect_url

    @property
    def scope(self) -> List[str]:
        return self._scope

    @property
    def token_url(self) -> str:
        return self._token_url

    @property
    def auth_url(self) -> str:
        return self._auth_url

    def from_dict(self, settings: dict):
        try:
            self._client_secret = settings['ClientSecret']
            self._redirect_url = settings['RedirectURL']
            self._scope = List(str, settings['Scope'])
            self._token_url = settings['TokenURL']
            self._auth_url = settings['AuthURL']
        except Exception as e:
            Console.error(f'[ ERROR ] [ {__name__} ]: Reading error in {type(self).__name__} settings')
            Console.error(f'[ EXCEPTION ] [ {__name__} ]: {e} -> {traceback.format_exc()}')
